Name:           cppcheck
Summary:        Static analysis tool for C/C++
Version:        2.3
Release:        %mkrel 1
License:        GPLv3+
Group:          Development/C++
Url:            http://cppcheck.sourceforge.net/
Source:         http://downloads.sourceforge.net/sourceforge/%{name}/%{name}-%{version}.tar.bz2
# See http://trac.cppcheck.net/ticket/7037
# Tests fail on i586 / 32-bit.
Patch1:         cppcheck-1.71-skip-failing-tests.patch

BuildRequires:  cmake
BuildRequires:  docbook-style-xsl
BuildRequires:  libxslt-proc
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(tinyxml2)
BuildRequires:  python3-setuptools

%description
This program tries to detect bugs that your C/C++ compiler does not
find. Cppcheck is versatile. You can check non-standard code that includes
various compiler extensions, inline assembly code, etc. One of its goals
is no false positives.

%prep
%autosetup -p1
rm -rf externals/tinyxml2

%build
%cmake -DHAVE_RULES=yes -DCFGDIR=%{_datadir}/%{name} -DUSE_BUNDLED_TINYXML2=OFF
%cmake_build

pushd htmlreport
%py3_build
popd

# this command line is documented inside cppcheck.1.xml
pushd man
xsltproc --nonet --param man.charmap.use.subset "0" \
   --param make.year.ranges "1" --param make.single.year.ranges "1" \
   /usr/share/sgml/docbook/xsl-stylesheets/manpages/docbook.xsl \
   cppcheck.1.xml
popd

%check
%ifnarch aarch64
make -C build test
%endif
true

%install
%cmake_install

pushd htmlreport
%py3_install
# We only want the binary.
rm -rf %{buildroot}%{python3_sitelib}/cppcheck*
popd

install -D -m 0644 man/cppcheck.1 %{buildroot}/%{_mandir}/man1/cppcheck.1

# Taken from the Fedora 22 .src.rpm - thanks!
# Install cfg files
cd cfg
for f in *; do
    install -D -p -m 644 $f %{buildroot}%{_datadir}/cppcheck/$f
done

%files
%doc AUTHORS readme.txt
%{_bindir}/cppcheck
%{_bindir}/cppcheck-htmlreport
%{_datadir}/Cppcheck/
%{_datadir}/cppcheck/
%{_mandir}/man1/cppcheck.1*


%changelog
* Wed Dec 30 2020 luigiwalser <luigiwalser> 2.3-1.mga8
+ Revision: 1665847
- 2.3
- remove patches 4 and 5 (fixed upstream)
- use cmake option to build against system tinyxml2

* Tue Nov 24 2020 akien <akien> 2.2-2.mga8
+ Revision: 1648911
- Install cppcheck-htmlreport

* Wed Oct 07 2020 shlomif <shlomif> 2.2-1.mga8
+ Revision: 1632541
- New version 2.2

* Fri Aug 21 2020 joequant <joequant> 2.1-2.mga8
+ Revision: 1617555
- fix cmake

* Thu Jun 25 2020 shlomif <shlomif> 2.1-1.mga8
+ Revision: 1599274
- New version 2.1

* Thu May 21 2020 shlomif <shlomif> 2.0-1.mga8
+ Revision: 1586612
- New version 2.0

* Tue Feb 18 2020 umeabot <umeabot> 1.90-2.mga8
+ Revision: 1541396
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Thu Dec 26 2019 shlomif <shlomif> 1.90-1.mga8
+ Revision: 1470154
- New version 1.90

* Sun Jul 07 2019 shlomif <shlomif> 1.88-1.mga8
+ Revision: 1419219
- New version 1.88

* Sun Feb 03 2019 pterjan <pterjan> 1.86-2.mga7
+ Revision: 1362955
- Drop char sign patch, seems fixed upstream and patch now breaks the tests

* Mon Jan 28 2019 shlomif <shlomif> 1.86-1.mga7
+ Revision: 1361595
- skip tests on failing archs
- New version 1.86
- New version 1.85
+ wally <wally>
- build with pcre

* Thu Oct 04 2018 wally <wally> 1.84-3.mga7
+ Revision: 1317537
- add patch based on one from Debian to build with system tinyxml2
- add patch to fix linking
- add Debian patch to fix check on aarch64

* Sun Sep 23 2018 umeabot <umeabot> 1.84-2.mga7
+ Revision: 1296846
- Mageia 7 Mass Rebuild

* Mon Aug 20 2018 shlomif <shlomif> 1.84-1.mga7
+ Revision: 1253079
- New version 1.84

* Tue May 15 2018 akien <akien> 1.83-2.mga7
+ Revision: 1229730
- Rebuild for tinyxml 6.2.0

* Mon Apr 16 2018 shlomif <shlomif> 1.83-1.mga7
+ Revision: 1219458
- New version 1.83

* Sat Feb 24 2018 shlomif <shlomif> 1.82-1.mga7
+ Revision: 1204857
- New version 1.82

* Fri Oct 20 2017 zezinho <zezinho> 1.81-1.mga7
+ Revision: 1172931
- new version

* Tue Sep 19 2017 shlomif <shlomif> 1.80-1.mga7
+ Revision: 1155445
- New version 1.80

* Tue Aug 08 2017 daviddavid <daviddavid> 1.79-2.mga7
+ Revision: 1138907
- rebuild for new tinyxml2 5.0.1

* Mon Jul 17 2017 shlomif <shlomif> 1.79-1.mga7
+ Revision: 1123939
- New version 1.79

* Sun Jan 15 2017 shlomif <shlomif> 1.77-1.mga6
+ Revision: 1081911
- New version 1.77.

* Thu May 12 2016 daviddavid <daviddavid> 1.72-2.mga6
+ Revision: 1014019
- replace some macros thus fixing build

* Wed Feb 10 2016 shlomif <shlomif> 1.72-1.mga6
+ Revision: 953310
- New version 1.72

* Mon Jan 04 2016 shlomif <shlomif> 1.71-2.mga6
+ Revision: 919548
- Skip failing tests
- New version 1.71

* Sat Oct 24 2015 shlomif <shlomif> 1.70-1.mga6
+ Revision: 894992
- New version 1.70

* Thu Jul 30 2015 shlomif <shlomif> 1.69-2.mga6
+ Revision: 859060
- Apply some fixes from the Fedora SPEC + Fix MGA#16471.
- Missing CFG files so it doesn't run properly.

* Sat Jun 20 2015 shlomif <shlomif> 1.69-1.mga6
+ Revision: 835823
- New version 1.69

* Wed Oct 15 2014 umeabot <umeabot> 1.65-3.mga5
+ Revision: 739066
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.65-2.mga5
+ Revision: 678567
- Mageia 5 Mass Rebuild

* Wed May 21 2014 shlomif <shlomif> 1.65-1.mga5
+ Revision: 624657
- New version 1.65

* Fri Feb 14 2014 kharec <kharec> 1.63-1.mga5
+ Revision: 591384
- new version 1.63

* Sat Oct 19 2013 umeabot <umeabot> 1.61-2.mga4
+ Revision: 531533
- Mageia 4 Mass Rebuild

* Mon Aug 05 2013 sander85 <sander85> 1.61-1.mga4
+ Revision: 463846
- New version: 1.61

* Wed Jun 05 2013 kharec <kharec> 1.60.1-1.mga4
+ Revision: 437563
- update to 1.60.1

* Thu May 23 2013 kharec <kharec> 1.59-1.mga4
+ Revision: 425109
- update to 1.59

* Mon Feb 25 2013 kharec <kharec> 1.58-1.mga3
+ Revision: 400313
- Fix rpm group
- new version 1.58

* Fri Jan 11 2013 umeabot <umeabot> 1.57-2.mga3
+ Revision: 348241
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 kamil <kamil> 1.57-1.mga3
+ Revision: 325241
- new version 1.57
- clean .spec

* Mon Sep 03 2012 shlomif <shlomif> 1.56-2.mga3
+ Revision: 287642
- fix description

* Mon Sep 03 2012 kharec <kharec> 1.56-1.mga3
+ Revision: 287622
- new version 1.56

* Thu Jul 05 2012 kharec <kharec> 1.55-1.mga3
+ Revision: 267970
- 1.55

* Mon May 28 2012 kharec <kharec> 1.54-1.mga3
+ Revision: 247930
- Update to 1.54 (many improves and bugfix)

* Tue Feb 21 2012 kharec <kharec> 1.53-1.mga2
+ Revision: 211581
- New version 1.53

* Mon Dec 12 2011 kharec <kharec> 1.52-1.mga2
+ Revision: 180843
- New version 1.52

* Sun Nov 20 2011 kharec <kharec> 1.51-1.mga2
+ Revision: 170013
- new version 1.51

* Sun Nov 20 2011 kharec <kharec> 1.47-1.mga2
+ Revision: 169901
- imported package cppcheck

